#
# spec file for package yadm
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           yadm
Version:        3.2.1
Release:        bp155.1.6
Summary:        Yet Another Dotfiles Manager
License:        GPL-3.0-only
Group:          Development/Tools/Version Control
URL:            https://yadm.io
Source0:        %{name}-%{version}.tar
Source99:       %{name}-rpmlintrc
Patch0:         %{name}-fix-makefile.patch
Patch1:         %{name}-fix-shebangs.patch
Requires:       bash
Requires:       git
BuildArch:      noarch

%description
yadm is a tool for managing a collection of files across multiple computers,
using a shared Git repository. In addition, yadm provides a feature to select
alternate versions of files based on the operation system or host name. Lastly,
yadm supplies the ability to manage a subset of secure files, which are
encrypted before they are included in the repository.

%package bash-completion
Summary:        Bash completions for %{name}
Requires:       bash-completion
Supplements:    (%{name} and bash-completion)
BuildArch:      noarch

%description bash-completion
The official bash completion script for %{name}.

%package fish-completion
Summary:        Fish Completion for %{name}
Supplements:    (%{name} and fish)
BuildArch:      noarch

%description fish-completion
The official fish completion script for %{name}.

%package zsh-completion
Summary:        ZSH Completion for %{name}
Supplements:    (%{name} and zsh)
BuildArch:      noarch

%description zsh-completion
The official zsh completion script for %{name}.

%prep
%setup -q
%patch0 -p1
%patch1 -p1

%build

%install
%make_install PREFIX=%{_prefix}

install -Dm0644 completion/fish/%{name}.fish %{buildroot}%{_datadir}/fish/vendor_completions.d/%{name}.fish
install -Dm0644 completion/bash/%{name} %{buildroot}%{_datadir}/bash-completion/completions/%{name}
install -Dm0644 completion/zsh/_%{name} %{buildroot}%{_datadir}/zsh/site-functions/_%{name}

%files
%{_bindir}/yadm
%{_mandir}/man1/%{name}.1%{?ext_man}
%doc CHANGES CONTRIBUTORS contrib/*
%license LICENSE

%files bash-completion
%{_datadir}/bash-completion

%files fish-completion
%{_datadir}/fish

%files zsh-completion
%{_datadir}/zsh/

%changelog
* Tue Mar 22 2022 Nicolas FORMICHELLA <stigpro@outlook.fr>
- Fix specfile to conform to packaging guidelines
  * Move yadm.rpmlintrc to yadm-rpmlintrc
  * Remove yadm.obscpio
* Tue Mar 22 2022 stigpro@outlook.fr
- Update to version 3.2.1:
  * Update version number and update documentation
  * Fix Bash 3 bad array subscript bug (#411)
  * Update version number and update documentation
  * Fix table format
  * Clarify requirements for linked directories (#328)
  * Adjust exempt labels
  * Add local.arch to config introspection
  * Reduce supported labels for architecture
  * Reorder list
  * Tweak stale workflow
  * Update yaml formatting
  * Change extension to match other workflows
  * Adding new github workflow for stale issues Adding a Github workflow that will mark issues that didn't have any activity on them for the last 60 days and put a label of stale on them. After 7 days if the stale issue didn't have any updates the issue will be deleted.
- Fix shebang patch
* Mon Mar 21 2022 Nicolas FORMICHELLA <stigpro@outlook.fr>
- Update to 3.2.0
  * Support architecture for alternates/templates (#202, #203, #393)
  * Support distro_family for alternates/templates (#213)
  * Support setting multiple classes (#185, #304)
  * Support environment variables in default template processor (#347)
  * Update version command to include Bash & Git versions (#377)
- Update shebang patch file to remove /bin/sh shebang and portability function
- Update makefile patch file to account for a part of the patch being patched upstream
* Thu Dec  9 2021 Nicolas FORMICHELLA <stigpro@outlook.fr>
- Fix specfile
- Changelog for 3.1.1
  * Fix clone support for older versions of Git (#348)
  * Fix support for multiple GPG recipients (#342)
  * Find symlinks in bootstrap-in-dir (#340)
- See CHANGES for the full changelog of previous versions
* Thu Nov 25 2021 Nicolas FORMICHELLA <stigpro@outlook.fr>
- Intial commit for v3.1.1
